@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Jakub Kruszona-Zawadzki, Core Technology Sp. z o.o.
+ * Copyright (C) 2023 Jakub Kruszona-Zawadzki, Saglabs SA
  * 
  * This file is part of MooseFS.
  * 
@@ -492,7 +492,11 @@ static void mfs_opt_parse_cfg_file(const char *filename,int optional,struct fuse
 	fd = fopen(filename,"r");
 	if (fd==NULL) {
 		if (optional==0) {
-			fprintf(stderr,"can't open cfg file: %s\n",filename);
+			if (errno==ENOENT) {
+				fprintf(stderr,"cfg file (%s) doesn't exist\n",filename);
+			} else {
+				fprintf(stderr,"can't open cfg file (%s), error: %s\n",filename,strerr(errno));
+			}
 			abort();
 		}
 		return;
@@ -601,7 +605,7 @@ static int mfs_opt_proc_stage2(void *data, const char *arg, int key, struct fuse
 		mfsopts.nostdmountoptions = 1;
 		return 0;
 	case KEY_VERSION:
-		fprintf(stderr, "MFS version %s\n",VERSSTR);
+		fprintf(stderr, "MFS version: %s ; build: %s\n",VERSSTR,STR(BUILDNO));
 #if FUSE_VERSION >= 30
 		fuse_lowlevel_version();
 #else
@@ -611,7 +615,7 @@ static int mfs_opt_proc_stage2(void *data, const char *arg, int key, struct fuse
 			fuse_opt_add_arg(&helpargs,outargs->argv[0]);
 			fuse_opt_add_arg(&helpargs,"--version");
 			fuse_parse_cmdline(&helpargs,NULL,NULL,NULL);
-			fuse_mount(NULL,&helpargs);
+			fuse_mount("",&helpargs);
 		}
 #endif
 		exit(0);
