@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Jakub Kruszona-Zawadzki, Core Technology Sp. z o.o.
+ * Copyright (C) 2023 Jakub Kruszona-Zawadzki, Saglabs SA
  * 
  * This file is part of MooseFS.
  * 
@@ -1055,10 +1055,12 @@ uint8_t wdlock(uint8_t runmode,uint32_t timeout) {
 			return 0;
 		}
 		if (runmode==RM_INFO) {
-#ifdef SIGINFO
+#if defined(SIGUSR1)
+			if (kill(ownerpid,SIGUSR1)<0) {
+#elif defined(SIGINFO)
 			if (kill(ownerpid,SIGINFO)<0) {
 #else
-			if (kill(ownerpid,SIGUSR1)<0) {
+			if (1) {
 #endif
 				mfs_errlog(LOG_WARNING,"can't send info signal to lock owner");
 				return 1;
@@ -1402,14 +1404,6 @@ int main(int argc,char **argv) {
 		mfs_syslog(LOG_WARNING,"default sysconf path has changed - please move " STR(APPNAME) ".cfg from "ETC_PATH"/ to "ETC_PATH"/mfs/");
 	}
 
-	if (runmode==RM_START || runmode==RM_RESTART || runmode==RM_TRY_RESTART) {
-		if (rundaemon) {
-			makedaemon();
-		} else {
-			set_signal_handlers(0);
-		}
-	}
-
 	if (cfg_load(cfgfile,logundefined)==0) {
 		if (userconfig) {
 			if (rundaemon) {
@@ -1423,6 +1417,14 @@ int main(int argc,char **argv) {
 	}
 	free(cfgfile);
 
+	if (runmode==RM_START || runmode==RM_RESTART || runmode==RM_TRY_RESTART) {
+		if (rundaemon) {
+			makedaemon();
+		} else {
+			set_signal_handlers(0);
+		}
+	}
+
 	processname_init(argc_back,argv_back); // prepare everything for 'processname_set'
 
 	logappname = cfg_getstr("SYSLOG_IDENT",STR(APPNAME));
@@ -1666,7 +1668,7 @@ int main(int argc,char **argv) {
 		}
 		ch=1;
 	}
-	mfs_syslog(LOG_NOTICE,"exititng ...");
+	mfs_syslog(LOG_NOTICE,"exiting ...");
 	destruct();
 	free_all_registered_entries();
 	signal_cleanup();
